import { CreateProductInput, DataService, GetProductDetailQuery, GetProductWithVariantsQuery, LanguageCode, UpdateProductInput, UpdateProductMutation, UpdateProductOptionInput, UpdateProductVariantInput, UpdateProductVariantsMutation } from '@uponcommerce/admin-ui/core';
import { Observable } from 'rxjs';
import { CreateProductVariantsConfig } from '../../components/generate-product-variants/generate-product-variants.component';
import * as i0 from "@angular/core";
/**
 * Handles the logic for making the API calls to perform CRUD operations on a Product and its related
 * entities. This logic was extracted out of the component because it became too large and hard to follow.
 */
export declare class ProductDetailService {
    private dataService;
    constructor(dataService: DataService);
    getTaxCategories(): Observable<{
        __typename?: "TaxCategory" | undefined;
        id: string;
        createdAt: any;
        updatedAt: any;
        name: string;
        isDefault: boolean;
    }[]>;
    createProductWithVariants(input: CreateProductInput, createVariantsConfig: CreateProductVariantsConfig, languageCode: LanguageCode): Observable<{
        createProductVariants: ({
            __typename?: "ProductVariant" | undefined;
            id: string;
            createdAt: any;
            updatedAt: any;
            enabled: boolean;
            languageCode: LanguageCode;
            name: string;
            price: number;
            currencyCode: import("@uponcommerce/admin-ui/core").CurrencyCode;
            priceWithTax: number;
            stockOnHand: number;
            stockAllocated: number;
            trackInventory: import("@uponcommerce/admin-ui/core").GlobalFlag;
            outOfStockThreshold: number;
            useGlobalOutOfStockThreshold: boolean;
            sku: string;
            taxRateApplied: {
                __typename?: "TaxRate" | undefined;
                id: string;
                name: string;
                value: number;
            };
            taxCategory: {
                __typename?: "TaxCategory" | undefined;
                id: string;
                name: string;
            };
            options: {
                __typename?: "ProductOption" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                code: string;
                languageCode: LanguageCode;
                name: string;
                groupId: string;
                translations: {
                    __typename?: "ProductOptionTranslation" | undefined;
                    id: string;
                    languageCode: LanguageCode;
                    name: string;
                }[];
            }[];
            facetValues: {
                __typename?: "FacetValue" | undefined;
                id: string;
                code: string;
                name: string;
                facet: {
                    __typename?: "Facet" | undefined;
                    id: string;
                    name: string;
                };
            }[];
            featuredAsset?: {
                __typename?: "Asset" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                name: string;
                fileSize: number;
                mimeType: string;
                type: import("@uponcommerce/admin-ui/core").AssetType;
                preview: string;
                source: string;
                width: number;
                height: number;
                focalPoint?: {
                    __typename?: "Coordinate" | undefined;
                    x: number;
                    y: number;
                } | null | undefined;
            } | null | undefined;
            assets: {
                __typename?: "Asset" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                name: string;
                fileSize: number;
                mimeType: string;
                type: import("@uponcommerce/admin-ui/core").AssetType;
                preview: string;
                source: string;
                width: number;
                height: number;
                focalPoint?: {
                    __typename?: "Coordinate" | undefined;
                    x: number;
                    y: number;
                } | null | undefined;
            }[];
            translations: {
                __typename?: "ProductVariantTranslation" | undefined;
                id: string;
                languageCode: LanguageCode;
                name: string;
            }[];
            channels: {
                __typename?: "Channel" | undefined;
                id: string;
                code: string;
            }[];
        } | null)[];
        productId: string;
    }>;
    createProductOptionGroups(groups: Array<{
        name: string;
        values: string[];
    }>, languageCode: LanguageCode): Observable<{
        __typename?: "ProductOptionGroup" | undefined;
        id: string;
        createdAt: any;
        updatedAt: any;
        languageCode: LanguageCode;
        code: string;
        name: string;
        translations: {
            __typename?: "ProductOptionGroupTranslation" | undefined;
            id: string;
            name: string;
        }[];
        options: {
            __typename?: "ProductOption" | undefined;
            id: string;
            languageCode: LanguageCode;
            name: string;
            code: string;
            translations: {
                __typename?: "ProductOptionTranslation" | undefined;
                name: string;
            }[];
        }[];
    }[]>;
    createProductVariants(product: {
        name: string;
        id: string;
    }, variantData: Array<{
        price: number;
        sku: string;
        stock: number;
        optionIds: string[];
    }>, options: Array<{
        id: string;
        name: string;
    }>, languageCode: LanguageCode): Observable<{
        createProductVariants: ({
            __typename?: "ProductVariant" | undefined;
            id: string;
            createdAt: any;
            updatedAt: any;
            enabled: boolean;
            languageCode: LanguageCode;
            name: string;
            price: number;
            currencyCode: import("@uponcommerce/admin-ui/core").CurrencyCode;
            priceWithTax: number;
            stockOnHand: number;
            stockAllocated: number;
            trackInventory: import("@uponcommerce/admin-ui/core").GlobalFlag;
            outOfStockThreshold: number;
            useGlobalOutOfStockThreshold: boolean;
            sku: string;
            taxRateApplied: {
                __typename?: "TaxRate" | undefined;
                id: string;
                name: string;
                value: number;
            };
            taxCategory: {
                __typename?: "TaxCategory" | undefined;
                id: string;
                name: string;
            };
            options: {
                __typename?: "ProductOption" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                code: string;
                languageCode: LanguageCode;
                name: string;
                groupId: string;
                translations: {
                    __typename?: "ProductOptionTranslation" | undefined;
                    id: string;
                    languageCode: LanguageCode;
                    name: string;
                }[];
            }[];
            facetValues: {
                __typename?: "FacetValue" | undefined;
                id: string;
                code: string;
                name: string;
                facet: {
                    __typename?: "Facet" | undefined;
                    id: string;
                    name: string;
                };
            }[];
            featuredAsset?: {
                __typename?: "Asset" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                name: string;
                fileSize: number;
                mimeType: string;
                type: import("@uponcommerce/admin-ui/core").AssetType;
                preview: string;
                source: string;
                width: number;
                height: number;
                focalPoint?: {
                    __typename?: "Coordinate" | undefined;
                    x: number;
                    y: number;
                } | null | undefined;
            } | null | undefined;
            assets: {
                __typename?: "Asset" | undefined;
                id: string;
                createdAt: any;
                updatedAt: any;
                name: string;
                fileSize: number;
                mimeType: string;
                type: import("@uponcommerce/admin-ui/core").AssetType;
                preview: string;
                source: string;
                width: number;
                height: number;
                focalPoint?: {
                    __typename?: "Coordinate" | undefined;
                    x: number;
                    y: number;
                } | null | undefined;
            }[];
            translations: {
                __typename?: "ProductVariantTranslation" | undefined;
                id: string;
                languageCode: LanguageCode;
                name: string;
            }[];
            channels: {
                __typename?: "Channel" | undefined;
                id: string;
                code: string;
            }[];
        } | null)[];
        productId: string;
    }>;
    updateProduct(updateOptions: {
        product: NonNullable<GetProductDetailQuery['product']>;
        languageCode: LanguageCode;
        autoUpdate: boolean;
        productInput?: UpdateProductInput;
        variantsInput?: UpdateProductVariantInput[];
    }): Observable<(UpdateProductMutation | UpdateProductVariantsMutation)[]>;
    updateProductOption(input: UpdateProductOptionInput & {
        autoUpdate: boolean;
    }, product: NonNullable<GetProductDetailQuery['product']>, languageCode: LanguageCode): Observable<any>;
    deleteProductVariant(id: string, productId: string): Observable<GetProductWithVariantsQuery>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProductDetailService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ProductDetailService>;
}
