import { Observable } from 'rxjs';
import { DataService } from '../../data/providers/data.service';
import { BulkAction } from '../../providers/bulk-action-registry/bulk-action-types';
import { BaseListComponent } from '../base-list.component';
import { DeletionResponse } from '../generated-types';
/**
 * @description
 * Resolves to an object containing the Channel code of the given channelId, or if no channelId
 * is supplied, the code of the activeChannel.
 */
export declare function getChannelCodeFromUserStatus(dataService: DataService, channelId?: string): Promise<{
    channelCode: string;
}>;
/**
 * @description
 * Resolves to `true` if multiple Channels are set up.
 */
export declare function isMultiChannel(dataService: DataService): Promise<boolean>;
/**
 * @description
 * Resolves to `true` if the current active Channel is not the default Channel.
 */
export declare function currentChannelIsNotDefault(dataService: DataService): Promise<boolean>;
export type CreateBulkDeleteActionConfig<ItemType> = Pick<BulkAction, 'location' | 'requiresPermission'> & {
    getItemName: (item: ItemType) => string;
    shouldRetryItem?: (response: DeletionResponse, item: ItemType) => boolean;
    bulkDelete: (dataService: DataService, ids: string[], retrying: boolean) => Observable<DeletionResponse[]>;
};
/**
 * @description
 * Creates a BulkAction which can be used to delete multiple items.
 */
export declare function createBulkDeleteAction<ItemType>(config: CreateBulkDeleteActionConfig<ItemType>): BulkAction<any, BaseListComponent<any, any, any>>;
