import { ActivatedRoute, Router } from '@angular/router';
import { CustomFieldConfig, DateOperators } from '../../common/generated-types';
import { DataTableFilter, DataTableFilterBooleanType, DataTableFilterCustomType, DataTableFilterDateRangeType, DataTableFilterNumberType, DataTableFilterOptions, DataTableFilterSelectType, DataTableFilterTextType, DataTableFilterType, DataTableFilterValue } from './data-table-filter';
export declare class FilterWithValue<Type extends DataTableFilterType = DataTableFilterType> {
    readonly filter: DataTableFilter<any, Type>;
    value: DataTableFilterValue<Type>;
    private onUpdateFns;
    constructor(filter: DataTableFilter<any, Type>, value: DataTableFilterValue<Type>, onUpdate?: (value: DataTableFilterValue<Type>) => void);
    onUpdate(fn: (value: DataTableFilterValue<Type>) => void): void;
    updateValue(value: DataTableFilterValue<Type>): void;
    isText(): this is FilterWithValue<DataTableFilterTextType>;
    isNumber(): this is FilterWithValue<DataTableFilterNumberType>;
    isBoolean(): this is FilterWithValue<DataTableFilterBooleanType>;
    isSelect(): this is FilterWithValue<DataTableFilterSelectType>;
    isDateRange(): this is FilterWithValue<DataTableFilterDateRangeType>;
    isCustom(): this is FilterWithValue<DataTableFilterCustomType>;
}
export declare class DataTableFilterCollection<FilterInput extends Record<string, any> = Record<string, any>> {
    #private;
    private router;
    valueChanges: import("rxjs").Observable<FilterWithValue<DataTableFilterType>[]>;
    constructor(router: Router);
    get length(): number;
    get activeFilters(): FilterWithValue[];
    addFilter<FilterType extends DataTableFilterType>(config: DataTableFilterOptions<FilterInput, FilterType>): DataTableFilterCollection<FilterInput>;
    addFilters<FilterType extends DataTableFilterType>(configs: Array<DataTableFilterOptions<FilterInput, FilterType>>): DataTableFilterCollection<FilterInput>;
    addDateFilters(): FilterInput extends {
        createdAt?: DateOperators | null;
        updatedAt?: DateOperators | null;
    } ? DataTableFilterCollection<FilterInput> : never;
    addCustomFieldFilters(customFields: CustomFieldConfig[]): this;
    getFilter(name: string): DataTableFilter<FilterInput> | undefined;
    getFilters(): Array<DataTableFilter<FilterInput>>;
    removeActiveFilterAtIndex(index: number): void;
    createFilterInput(): FilterInput;
    connectToRoute(route: ActivatedRoute): this;
    serializeValue<Type extends DataTableFilterType>(filterWithValue: FilterWithValue<Type>): string | undefined;
    deserializeValue(filter: DataTableFilter, value: string): DataTableFilterValue<DataTableFilterType>;
    private serialize;
    private onActivateFilter;
    private createFacetWithValue;
}
