import { AfterViewInit, OnDestroy, OnInit } from '@angular/core';
import { PaginationInstance } from 'ngx-pagination';
import { BehaviorSubject, Observable } from 'rxjs';
import { Asset, TagFragment } from '../../../common/generated-types';
import { DataService } from '../../../data/providers/data.service';
import { Dialog } from '../../../providers/modal/modal.types';
import { NotificationService } from '../../../providers/notification/notification.service';
import { AssetLike } from '../asset-gallery/asset-gallery.types';
import * as i0 from "@angular/core";
/**
 * @description
 * A dialog which allows the creation and selection of assets.
 *
 * @example
 * ```TypeScript
 * selectAssets() {
 *   this.modalService
 *     .fromComponent(AssetPickerDialogComponent, {
 *         size: 'xl',
 *     })
 *     .subscribe(result => {
 *         if (result && result.length) {
 *             // ...
 *         }
 *     });
 * }
 * ```
 *
 * @docsCategory components
 */
export declare class AssetPickerDialogComponent implements OnInit, AfterViewInit, OnDestroy, Dialog<Asset[]> {
    private dataService;
    private notificationService;
    assets$: Observable<AssetLike[]>;
    allTags$: Observable<TagFragment[]>;
    paginationConfig: PaginationInstance;
    private assetSearchInputComponent;
    private assetGalleryComponent;
    multiSelect: boolean;
    initialTags: string[];
    resolveWith: (result?: Asset[]) => void;
    selection: Asset[];
    searchTerm$: BehaviorSubject<string | undefined>;
    filterByTags$: BehaviorSubject<TagFragment[] | undefined>;
    uploading: boolean;
    private listQuery;
    private destroy$;
    constructor(dataService: DataService, notificationService: NotificationService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    pageChange(page: number): void;
    itemsPerPageChange(itemsPerPage: number): void;
    cancel(): void;
    select(): void;
    createAssets(files: File[]): void;
    private fetchPage;
    static ɵfac: i0.ɵɵFactoryDeclaration<AssetPickerDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AssetPickerDialogComponent, "vdr-asset-picker-dialog", never, {}, {}, never, never, false, never>;
}
