import { AfterContentInit, ChangeDetectorRef, EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { LanguageCode } from '../../../common/generated-types';
import { DataService } from '../../../data/providers/data.service';
import { DataTableFilterCollection } from '../../../providers/data-table/data-table-filter-collection';
import { DataTableConfig, LocalStorageService } from '../../../providers/local-storage/local-storage.service';
import { BulkActionMenuComponent } from '../bulk-action-menu/bulk-action-menu.component';
import { DataTable2ColumnComponent } from './data-table-column.component';
import { DataTableCustomFieldColumnComponent } from './data-table-custom-field-column.component';
import { DataTable2SearchComponent } from './data-table-search.component';
import * as i0 from "@angular/core";
/**
 * @description
 * A table for displaying PaginatedList results. It is designed to be used inside components which
 * extend the {@link BaseListComponent} class.
 *
 * @example
 * ```HTML
 * <vdr-data-table
 *   [items]="items$ | async"
 *   [itemsPerPage]="itemsPerPage$ | async"
 *   [totalItems]="totalItems$ | async"
 *   [currentPage]="currentPage$ | async"
 *   (pageChange)="setPageNumber($event)"
 *   (itemsPerPageChange)="setItemsPerPage($event)"
 * >
 *   <!-- The header columns are defined first -->
 *   <vdr-dt-column>{{ 'common.name' | translate }}</vdr-dt-column>
 *   <vdr-dt-column></vdr-dt-column>
 *   <vdr-dt-column></vdr-dt-column>
 *
 *   <!-- Then we define how a row is rendered -->
 *   <ng-template let-taxRate="item">
 *     <td class="left align-middle">{{ taxRate.name }}</td>
 *     <td class="left align-middle">{{ taxRate.category.name }}</td>
 *     <td class="left align-middle">{{ taxRate.zone.name }}</td>
 *     <td class="left align-middle">{{ taxRate.value }}%</td>
 *     <td class="right align-middle">
 *       <vdr-table-row-action
 *         iconShape="edit"
 *         [label]="'common.edit' | translate"
 *         [linkTo]="['./', taxRate.id]"
 *       ></vdr-table-row-action>
 *     </td>
 *     <td class="right align-middle">
 *       <vdr-dropdown>
 *         <button type="button" class="btn btn-link btn-sm" vdrDropdownTrigger>
 *           {{ 'common.actions' | translate }}
 *           <clr-icon shape="caret down"></clr-icon>
 *         </button>
 *         <vdr-dropdown-menu vdrPosition="bottom-right">
 *           <button
 *               type="button"
 *               class="delete-button"
 *               (click)="deleteTaxRate(taxRate)"
 *               [disabled]="!(['DeleteSettings', 'DeleteTaxRate'] | hasPermission)"
 *               vdrDropdownItem
 *           >
 *               <clr-icon shape="trash" class="is-danger"></clr-icon>
 *               {{ 'common.delete' | translate }}
 *           </button>
 *         </vdr-dropdown-menu>
 *       </vdr-dropdown>
 *     </td>
 *   </ng-template>
 * </vdr-data-table>
 * ```
 *
 * @docsCategory components
 */
export declare class DataTable2Component<T> implements AfterContentInit, OnChanges, OnInit, OnDestroy {
    protected changeDetectorRef: ChangeDetectorRef;
    protected localStorageService: LocalStorageService;
    protected dataService: DataService;
    id: string;
    items: T[];
    itemsPerPage: number;
    currentPage: number;
    totalItems: number;
    emptyStateLabel: string;
    filters: DataTableFilterCollection;
    activeIndex: number;
    pageChange: EventEmitter<number>;
    itemsPerPageChange: EventEmitter<number>;
    columns: QueryList<DataTable2ColumnComponent<T>>;
    customFieldColumns: QueryList<DataTableCustomFieldColumnComponent<T>>;
    searchComponent: DataTable2SearchComponent;
    bulkActionMenuComponent: BulkActionMenuComponent;
    customSearchTemplate: TemplateRef<any>;
    templateRefs: QueryList<TemplateRef<any>>;
    rowTemplate: TemplateRef<any>;
    currentStart: number;
    currentEnd: number;
    disableSelect: boolean;
    showSearchFilterRow: boolean;
    protected uiLanguage$: Observable<LanguageCode>;
    private subscription;
    constructor(changeDetectorRef: ChangeDetectorRef, localStorageService: LocalStorageService, dataService: DataService);
    get selectionManager(): import("@uponcommerce/admin-ui/core").SelectionManager<any>;
    get allColumns(): DataTable2ColumnComponent<T>[];
    get visibleSortedColumns(): DataTable2ColumnComponent<T>[];
    get sortedColumns(): DataTable2ColumnComponent<T>[];
    private shiftDownHandler;
    private shiftUpHandler;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    ngAfterContentInit(): void;
    onColumnReorder(event: {
        column: DataTable2ColumnComponent<any>;
        newIndex: number;
    }): void;
    onColumnsReset(): void;
    toggleSearchFilterRow(): void;
    trackByFn(index: number, item: any): any;
    onToggleAllClick(): void;
    onRowClick(item: T, event: MouseEvent): void;
    protected getDataTableConfig(): DataTableConfig;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTable2Component<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTable2Component<any>, "vdr-data-table-2", never, { "id": { "alias": "id"; "required": false; }; "items": { "alias": "items"; "required": false; }; "itemsPerPage": { "alias": "itemsPerPage"; "required": false; }; "currentPage": { "alias": "currentPage"; "required": false; }; "totalItems": { "alias": "totalItems"; "required": false; }; "emptyStateLabel": { "alias": "emptyStateLabel"; "required": false; }; "filters": { "alias": "filters"; "required": false; }; "activeIndex": { "alias": "activeIndex"; "required": false; }; }, { "pageChange": "pageChange"; "itemsPerPageChange": "itemsPerPageChange"; }, ["searchComponent", "bulkActionMenuComponent", "customSearchTemplate", "columns", "customFieldColumns", "templateRefs"], ["vdr-bulk-action-menu"], false, never>;
}
