import { EventEmitter, OnInit } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { ProductSelectorSearchQuery } from '../../../common/generated-types';
import { DataService } from '../../../data/providers/data.service';
import * as i0 from "@angular/core";
/**
 * @description
 * A component for selecting product variants via an autocomplete-style select input.
 *
 * @example
 * ```HTML
 * <vdr-product-variant-selector
 *   (productSelected)="selectResult($event)"></vdr-product-selector>
 * ```
 *
 * @docsCategory components
 */
export declare class ProductVariantSelectorComponent implements OnInit {
    private dataService;
    searchInput$: Subject<string>;
    searchLoading: boolean;
    searchResults$: Observable<ProductSelectorSearchQuery['search']['items']>;
    productSelected: EventEmitter<{
        __typename?: "SearchResult" | undefined;
        productVariantId: string;
        productVariantName: string;
        sku: string;
        productAsset?: {
            __typename?: "SearchResultAsset" | undefined;
            id: string;
            preview: string;
            focalPoint?: {
                __typename?: "Coordinate" | undefined;
                x: number;
                y: number;
            } | null | undefined;
        } | null | undefined;
        price: {
            __typename?: "PriceRange" | undefined;
        } | {
            __typename?: "SinglePrice" | undefined;
            value: number;
        };
        priceWithTax: {
            __typename?: "PriceRange" | undefined;
        } | {
            __typename?: "SinglePrice" | undefined;
            value: number;
        };
    }>;
    private ngSelect;
    constructor(dataService: DataService);
    ngOnInit(): void;
    private initSearchResults;
    selectResult(product?: ProductSelectorSearchQuery['search']['items'][number]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProductVariantSelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ProductVariantSelectorComponent, "vdr-product-variant-selector", never, {}, { "productSelected": "productSelected"; }, never, never, false, never>;
}
